@@ -1,5 +1,5 @@
 import pipeline
-from screens import ExceptionScreen, StopProcessingScreen
+from screens import ExceptionScreen, StopProcessingScreen, RetryScreen
 import logging
 module_logger = logging.getLogger(__name__)
 
@@ -22,5 +22,16 @@ class PipeFitting(BaseFitting):
 		stop_processing_screen = StopProcessingScreen(self.Execute)
 		exception_screen = ExceptionScreen(stop_processing_screen.Execute)
 		return exception_screen.Execute(msg)
+		
+		
+class RetryFitting(BaseFitting):
+	def __init__(self, maxRetry = 3, slideTime = 1):
+		self.maxRetry = maxRetry
+		self.slideTime = slideTime
+		BaseFitting.__init__(self)
 			
-	
\ No newline at end of file
+	def Invoke(self, msg):
+		retry_screen = RetryScreen(self.Execute, self.maxRetry, self.slideTime)
+		stop_processing_screen = StopProcessingScreen(retry_screen.Execute)
+		exception_screen = ExceptionScreen(stop_processing_screen.Execute)
+		return exception_screen.Execute(msg)
\ No newline at end of file
